@@ -5,13 +5,13 @@ use base qw{Pod::Parser};
 use Hash::Merge qw(merge);
 
 # Set our version
-our $VERSION = '0.005';
+our $VERSION = '0.010';
 
 =pod
 
 =head1 VERSION
 
-0.005
+0.010
 
 =cut
 
@@ -70,6 +70,7 @@ sub instance000 {
         : ($$instance = $class->_instance(@_));
 }
 
+my $instance;
 sub instance {
     my ($class, $file, %arg) = @_;
     $scope = 'instance';
@@ -83,7 +84,7 @@ sub instance {
         if $arg{template} && %{$arg{template}};
     
     $class->_process( $file,);
-    bless \%sql, $class;
+    $instance ||= bless \%sql, $class;
 }
 
 sub _process {# pos file
@@ -325,7 +326,7 @@ DBIx::POS::Template - is a fork of L<DBIx::POS>. Define a dictionary of SQL stat
   
     # Some arbitrary parameters as perl code (eval)
     {
-        cache=>1,
+        cache=>1, # will be prepare_cached
     }
 
   =sql
@@ -336,7 +337,19 @@ DBIx::POS::Template - is a fork of L<DBIx::POS>. Define a dictionary of SQL stat
 
   =cut
 
+Or:
 
+  package POS::Foo;
+  use DBIx::POS::Template;
+  use Hash::Merge qw(merge);
+  
+  my $default = {foo=>'bar',};
+  
+  sub new {
+    my $proto = shift;
+    DBIx::POS::Template->new(__FILE__, template => merge({@_}, $default));
+    # or DBIx::POS::Template->instance(...
+  }
 
 =head1 DESCRIPTION
 
@@ -398,6 +411,8 @@ L<DBIx::POS>
 
 L<Text::Template>
 
+L<DBIx::POS::Sth>
+
 =head1 AUTHOR
 
 Михаил Че (Mikhail Che), C<< <mche[-at-]cpan.org> >>
